X-Original-To: pgsql-performance-postgresql.org@localhost.postgresql.org Received: from localhost (av.hub.org [200.46.204.144]) by svr1.postgresql.org (Postfix) with ESMTP id 95C3AD90CA for ; Thu, 22 Sep 2005 18:58:55 -0300 (ADT) Received: from svr1.postgresql.org ([200.46.204.71]) by localhost (av.hub.org [200.46.204.144]) (amavisd-new, port 10024) with ESMTP id 25111-09 for ; Thu, 22 Sep 2005 21:58:47 +0000 (GMT) Received: from BAYC1-PASMTP02.BAYC1.HOTMAIL.COM (bayc1-pasmtp02.bayc1.hotmail.com [65.54.191.162]) by svr1.postgresql.org (Postfix) with ESMTP id 96E14D901E for ; Thu, 22 Sep 2005 18:58:47 -0300 (ADT) Message-ID: X-Originating-IP: [70.50.100.93] X-Originating-Email: [pelletier_32@sympatico.ca] Received: from JP ([70.50.100.93]) by BAYC1-PASMTP02.BAYC1.HOTMAIL.COM over TLS secured channel with Microsoft SMTPSVC(6.0.3790.1830); Thu, 22 Sep 2005 14:58:17 -0700 Message-ID: <012501c5bfc0$d1122320$6501a8c0@JP> From: "Jean-Pierre Pelletier" To: "John Arbash Meinel" Cc: References: <433326A6.8010708@arbash-meinel.com> Subject: Re: Queries 15 times slower on 8.1 beta 2 than on 8.0 Date: Thu, 22 Sep 2005 17:58:49 -0400 MIME-Version: 1.0 Content-Type: text/plain; format=flowed; charset="iso-8859-1"; reply-type=original Content-Transfer-Encoding: 7bit X-Priority: 3 X-MSMail-Priority: Normal X-Mailer: Microsoft Outlook Express 6.00.2900.2670 X-MimeOLE: Produced By Microsoft MimeOLE V6.00.2900.2670 X-OriginalArrivalTime: 22 Sep 2005 21:58:17.0408 (UTC) FILETIME=[BCEB2400:01C5BFC0] X-Virus-Scanned: by amavisd-new at hub.org X-Spam-Status: No, hits=0.523 required=5 tests=[AWL=0.007, FROM_ENDS_IN_NUMS=0.516, MSGID_FROM_MTA_HEADER=0] X-Spam-Level: X-Archive-Number: 200509/253 X-Sequence-Number: 14561 Here are the explain analyze: On 8.1 beta2: "Nested Loop Left Join (cost=0.00..18591.77 rows=1 width=0) (actual time=1320.302..2439.066 rows=1 loops=1)" " Join Filter: ("outer".priceid = "inner".priceid)" " -> Nested Loop Left Join (cost=0.00..5.59 rows=1 width=4) (actual time=0.044..0.058 rows=1 loops=1)" " -> Seq Scan on content c (cost=0.00..1.01 rows=1 width=8) (actual time=0.009..0.011 rows=1 loops=1)" " -> Index Scan using "Supplier Id" on supplier s (cost=0.00..4.56 rows=1 width=4) (actual time=0.016..0.022 rows=1 loops=1)" " Index Cond: ("outer".supplierid = s.supplierid)" " -> Seq Scan on price p (cost=0.00..11317.75 rows=581475 width=4) (actual time=0.004..1143.720 rows=581475 loops=1)" "Total runtime: 2439.211 ms" On 8.0.1: "Nested Loop Left Join (cost=0.00..11.02 rows=1 width=0) (actual time=0.000..0.000 rows=1 loops=1)" " -> Nested Loop Left Join (cost=0.00..5.48 rows=1 width=4) (actual time=0.000..0.000 rows=1 loops=1)" " -> Seq Scan on content c (cost=0.00..1.01 rows=1 width=8) (actual time=0.000..0.000 rows=1 loops=1)" " -> Index Scan using "Supplier Id" on supplier s (cost=0.00..4.46 rows=1 width=4) (actual time=0.000..0.000 rows=1 loops=1)" " Index Cond: ("outer".supplierid = s.supplierid)" " -> Index Scan using "Price Id" on price p (cost=0.00..5.53 rows=1 width=4) (actual time=0.000..0.000 rows=1 loops=1)" " Index Cond: ("outer".priceid = p.priceid)" "Total runtime: 0.000 ms" ----- Original Message ----- From: "John Arbash Meinel" To: "Jean-Pierre Pelletier" Cc: Sent: Thursday, September 22, 2005 5:48 PM Subject: Re: [PERFORM] Queries 15 times slower on 8.1 beta 2 than on 8.0